# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _medenumtest
else:
    import _medenumtest

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


HAVE_CC_C99 = _medenumtest.HAVE_CC_C99
HAVE_CUSERID = _medenumtest.HAVE_CUSERID
HAVE_DLFCN_H = _medenumtest.HAVE_DLFCN_H
HAVE_FTIME = _medenumtest.HAVE_FTIME
HAVE_GETEUID = _medenumtest.HAVE_GETEUID
HAVE_GETPWUID = _medenumtest.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medenumtest.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medenumtest.HAVE_H5PUBLIC_H
HAVE_INT64 = _medenumtest.HAVE_INT64
HAVE_INTTYPES_H = _medenumtest.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medenumtest.HAVE_MALLOC_H
HAVE_PWD_H = _medenumtest.HAVE_PWD_H
HAVE_STDBOOL_H = _medenumtest.HAVE_STDBOOL_H
HAVE_STDINT_H = _medenumtest.HAVE_STDINT_H
HAVE_STDIO_H = _medenumtest.HAVE_STDIO_H
HAVE_STDLIB_H = _medenumtest.HAVE_STDLIB_H
HAVE_STRINGS_H = _medenumtest.HAVE_STRINGS_H
HAVE_STRING_H = _medenumtest.HAVE_STRING_H
HAVE_SYS_STAT_H = _medenumtest.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medenumtest.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medenumtest.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medenumtest.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medenumtest.HAVE_UNISTD_H
HAVE__BOOL = _medenumtest.HAVE__BOOL
MED_CHECK_23FORMAT = _medenumtest.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medenumtest.MED_HAVE_FORTRAN
MESGERR = _medenumtest.MESGERR
PACKAGE = _medenumtest.PACKAGE
PACKAGE_BUGREPORT = _medenumtest.PACKAGE_BUGREPORT
PACKAGE_NAME = _medenumtest.PACKAGE_NAME
PACKAGE_STRING = _medenumtest.PACKAGE_STRING
PACKAGE_URL = _medenumtest.PACKAGE_URL
PACKAGE_VERSION = _medenumtest.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medenumtest.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medenumtest.SIZEOF_INT
SIZEOF_LONG = _medenumtest.SIZEOF_LONG
STDC_HEADERS = _medenumtest.STDC_HEADERS
VERSION = _medenumtest.VERSION
HDF_VERSION_REF = _medenumtest.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medenumtest.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medenumtest.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medenumtest.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medenumtest.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medenumtest.H5F_LIBVER_18
MED_MAJOR_NUM = _medenumtest.MED_MAJOR_NUM
MED_MINOR_NUM = _medenumtest.MED_MINOR_NUM
MED_RELEASE_NUM = _medenumtest.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medenumtest.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medenumtest.MED_4_LATEST_MINOR
MED_5_LATEST_MINOR = _medenumtest.MED_5_LATEST_MINOR
MED_50_LATEST_RELEASE = _medenumtest.MED_50_LATEST_RELEASE
MED_NUM_MAJEUR = _medenumtest.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medenumtest.MED_NUM_MINEUR
MED_NUM_RELEASE = _medenumtest.MED_NUM_RELEASE
MED_VERSION_STR = _medenumtest.MED_VERSION_STR
MED_MAX_PARA = _medenumtest.MED_MAX_PARA
MED_COMMENT_SIZE = _medenumtest.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medenumtest.MED_IDENT_SIZE
MED_NAME_SIZE = _medenumtest.MED_NAME_SIZE
MED_SNAME_SIZE = _medenumtest.MED_SNAME_SIZE
MED_LNAME_SIZE = _medenumtest.MED_LNAME_SIZE
MED_SNAME_BLANK = _medenumtest.MED_SNAME_BLANK
MED_NAME_BLANK = _medenumtest.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medenumtest.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medenumtest.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medenumtest.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medenumtest.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medenumtest.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medenumtest.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medenumtest.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medenumtest.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medenumtest.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medenumtest.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medenumtest.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medenumtest.MED_ACC_RDONLY
MED_ACC_RDWR = _medenumtest.MED_ACC_RDWR
MED_ACC_RDEXT = _medenumtest.MED_ACC_RDEXT
MED_ACC_CREAT = _medenumtest.MED_ACC_CREAT
MED_ACC_UNDEF = _medenumtest.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medenumtest.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medenumtest.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medenumtest.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medenumtest.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medenumtest.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medenumtest.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medenumtest.MED_UNDEF_GRID_TYPE
MED_CELL = _medenumtest.MED_CELL
MED_DESCENDING_FACE = _medenumtest.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medenumtest.MED_DESCENDING_EDGE
MED_NODE = _medenumtest.MED_NODE
MED_NODE_ELEMENT = _medenumtest.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medenumtest.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medenumtest.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medenumtest.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medenumtest.MED_N_ENTITY_TYPES
MED_COORDINATE = _medenumtest.MED_COORDINATE
MED_CONNECTIVITY = _medenumtest.MED_CONNECTIVITY
MED_NAME = _medenumtest.MED_NAME
MED_NUMBER = _medenumtest.MED_NUMBER
MED_FAMILY_NUMBER = _medenumtest.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medenumtest.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medenumtest.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medenumtest.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medenumtest.MED_INDEX_FACE
MED_INDEX_NODE = _medenumtest.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medenumtest.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medenumtest.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medenumtest.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medenumtest.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medenumtest.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medenumtest.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medenumtest.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medenumtest.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medenumtest.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medenumtest.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medenumtest.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medenumtest.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medenumtest.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medenumtest.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medenumtest.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medenumtest.MED_INTERNAL_UNDEF
MED_DOUBLE = _medenumtest.MED_DOUBLE
MED_FLOAT64 = _medenumtest.MED_FLOAT64
MED_FLOAT32 = _medenumtest.MED_FLOAT32
MED_INT32 = _medenumtest.MED_INT32
MED_INT64 = _medenumtest.MED_INT64
MED_INT = _medenumtest.MED_INT
MED_ATT_FLOAT64 = _medenumtest.MED_ATT_FLOAT64
MED_ATT_INT = _medenumtest.MED_ATT_INT
MED_ATT_NAME = _medenumtest.MED_ATT_NAME
MED_ATT_UNDEF = _medenumtest.MED_ATT_UNDEF
MED_MESH = _medenumtest.MED_MESH
MED_FIELD = _medenumtest.MED_FIELD
MED_LIBRARY = _medenumtest.MED_LIBRARY
MED_FILE = _medenumtest.MED_FILE
MED_MESH_SUPPORT = _medenumtest.MED_MESH_SUPPORT
MED_ELSTRUCT = _medenumtest.MED_ELSTRUCT
MED_FAMILY = _medenumtest.MED_FAMILY
MED_EQUIVALENCE = _medenumtest.MED_EQUIVALENCE
MED_GROUP = _medenumtest.MED_GROUP
MED_JOINT = _medenumtest.MED_JOINT
MED_LOCALIZATION = _medenumtest.MED_LOCALIZATION
MED_PROFILE = _medenumtest.MED_PROFILE
MED_FILTER = _medenumtest.MED_FILTER
MED_INTERPOLATION = _medenumtest.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medenumtest.MED_NUMERICAL_DATA
MED_LINK = _medenumtest.MED_LINK
MED_CLASS_UNDEF = _medenumtest.MED_CLASS_UNDEF
MED_CLASS_ALL = _medenumtest.MED_CLASS_ALL
MED_POINT1 = _medenumtest.MED_POINT1
MED_SEG2 = _medenumtest.MED_SEG2
MED_SEG3 = _medenumtest.MED_SEG3
MED_SEG4 = _medenumtest.MED_SEG4
MED_TRIA3 = _medenumtest.MED_TRIA3
MED_QUAD4 = _medenumtest.MED_QUAD4
MED_TRIA6 = _medenumtest.MED_TRIA6
MED_TRIA7 = _medenumtest.MED_TRIA7
MED_QUAD8 = _medenumtest.MED_QUAD8
MED_QUAD9 = _medenumtest.MED_QUAD9
MED_TETRA4 = _medenumtest.MED_TETRA4
MED_PYRA5 = _medenumtest.MED_PYRA5
MED_PENTA6 = _medenumtest.MED_PENTA6
MED_HEXA8 = _medenumtest.MED_HEXA8
MED_TETRA10 = _medenumtest.MED_TETRA10
MED_OCTA12 = _medenumtest.MED_OCTA12
MED_PYRA13 = _medenumtest.MED_PYRA13
MED_PENTA15 = _medenumtest.MED_PENTA15
MED_PENTA18 = _medenumtest.MED_PENTA18
MED_HEXA20 = _medenumtest.MED_HEXA20
MED_HEXA27 = _medenumtest.MED_HEXA27
MED_POLYGON = _medenumtest.MED_POLYGON
MED_POLYGON2 = _medenumtest.MED_POLYGON2
MED_POLYHEDRON = _medenumtest.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medenumtest.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medenumtest.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medenumtest.MED_NONE
MED_NO_GEOTYPE = _medenumtest.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medenumtest.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medenumtest.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medenumtest.MED_ALL_GEOTYPE
MED_GEO_ALL = _medenumtest.MED_GEO_ALL
MED_N_CELL_GEO = _medenumtest.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medenumtest.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medenumtest.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medenumtest.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medenumtest.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medenumtest.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medenumtest.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medenumtest.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medenumtest.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medenumtest.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medenumtest.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medenumtest.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medenumtest.MED_NODAL
MED_DESCENDING = _medenumtest.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medenumtest.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medenumtest.MED_NO_CMODE
MED_CARTESIAN = _medenumtest.MED_CARTESIAN
MED_CYLINDRICAL = _medenumtest.MED_CYLINDRICAL
MED_SPHERICAL = _medenumtest.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medenumtest.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medenumtest.MED_FALSE
MED_TRUE = _medenumtest.MED_TRUE
MED_GAUSS_ELNO = _medenumtest.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medenumtest.MED_IPOINT_ELNO
MED_NO_NAME = _medenumtest.MED_NO_NAME
MED_NO_MESHNAME = _medenumtest.MED_NO_MESHNAME
MED_NO_MESH = _medenumtest.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medenumtest.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medenumtest.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medenumtest.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medenumtest.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medenumtest.MED_NO_PROFILE
MED_NO_GROUP = _medenumtest.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medenumtest.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medenumtest.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medenumtest.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medenumtest.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medenumtest.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medenumtest.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medenumtest.MED_SORT_DTIT
MED_SORT_ITDT = _medenumtest.MED_SORT_ITDT
MED_SORT_UNDEF = _medenumtest.MED_SORT_UNDEF
MED_ALL_DT = _medenumtest.MED_ALL_DT
MED_ALL_IT = _medenumtest.MED_ALL_IT
MED_NO_DT = _medenumtest.MED_NO_DT
MED_NO_IT = _medenumtest.MED_NO_IT
MED_UNDEF_DT = _medenumtest.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medenumtest.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medenumtest.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medenumtest.med_filter_nspaces_get, _medenumtest.med_filter_nspaces_set)
    memspace = property(_medenumtest.med_filter_memspace_get, _medenumtest.med_filter_memspace_set)
    diskspace = property(_medenumtest.med_filter_diskspace_get, _medenumtest.med_filter_diskspace_set)
    nentity = property(_medenumtest.med_filter_nentity_get, _medenumtest.med_filter_nentity_set)
    nvaluesperentity = property(_medenumtest.med_filter_nvaluesperentity_get, _medenumtest.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medenumtest.med_filter_nconstituentpervalue_get, _medenumtest.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medenumtest.med_filter_constituentselect_get, _medenumtest.med_filter_constituentselect_set)
    switchmode = property(_medenumtest.med_filter_switchmode_get, _medenumtest.med_filter_switchmode_set)
    filterarraysize = property(_medenumtest.med_filter_filterarraysize_get, _medenumtest.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medenumtest.med_filter_filterarray23v30_get, _medenumtest.med_filter_filterarray23v30_set)
    profilearraysize = property(_medenumtest.med_filter_profilearraysize_get, _medenumtest.med_filter_profilearraysize_set)
    storagemode = property(_medenumtest.med_filter_storagemode_get, _medenumtest.med_filter_storagemode_set)
    profilename = property(_medenumtest.med_filter_profilename_get, _medenumtest.med_filter_profilename_set)

    def __init__(self):
        _medenumtest.med_filter_swiginit(self, _medenumtest.new_med_filter())
    __swig_destroy__ = _medenumtest.delete_med_filter

# Register med_filter in _medenumtest:
_medenumtest.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medenumtest.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medenumtest.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medenumtest.med_file_version_majeur_get, _medenumtest.med_file_version_majeur_set)
    mineur = property(_medenumtest.med_file_version_mineur_get, _medenumtest.med_file_version_mineur_set)
    release = property(_medenumtest.med_file_version_release_get, _medenumtest.med_file_version_release_set)

    def __init__(self):
        _medenumtest.med_file_version_swiginit(self, _medenumtest.new_med_file_version())
    __swig_destroy__ = _medenumtest.delete_med_file_version

# Register med_file_version in _medenumtest:
_medenumtest.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medenumtest.med_memfile_app_image_ptr_get, _medenumtest.med_memfile_app_image_ptr_set)
    app_image_size = property(_medenumtest.med_memfile_app_image_size_get, _medenumtest.med_memfile_app_image_size_set)
    ref_count = property(_medenumtest.med_memfile_ref_count_get, _medenumtest.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medenumtest.med_memfile_fapl_image_ptr_get, _medenumtest.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medenumtest.med_memfile_fapl_image_size_get, _medenumtest.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medenumtest.med_memfile_fapl_ref_count_get, _medenumtest.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medenumtest.med_memfile_vfd_image_ptr_get, _medenumtest.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medenumtest.med_memfile_vfd_image_size_get, _medenumtest.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medenumtest.med_memfile_vfd_ref_count_get, _medenumtest.med_memfile_vfd_ref_count_set)
    flags = property(_medenumtest.med_memfile_flags_get, _medenumtest.med_memfile_flags_set)

    def __init__(self):
        _medenumtest.med_memfile_swiginit(self, _medenumtest.new_med_memfile())
    __swig_destroy__ = _medenumtest.delete_med_memfile

# Register med_memfile in _medenumtest:
_medenumtest.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medenumtest.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medenumtest.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medenumtest.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medenumtest.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medenumtest.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medenumtest.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medenumtest.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medenumtest.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medenumtest.MED_PARTICLE_NAME
MED_BALL_NAME = _medenumtest.MED_BALL_NAME
MED_BEAM_NAME = _medenumtest.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medenumtest.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medenumtest.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medenumtest.MED_BEAM_THICKNESS

cvar = _medenumtest.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT

